
# Slot: id


Different classes of agents have distinct preferred identifiers. For publishers, use the ISBN publisher code. See https://grp.isbn-international.org/ for publisher code lookups. For editors, authors and  individual providers, use the individual's ORCID if available; Otherwise, a ScopusID, ResearchID or Google Scholar ID ('GSID') may be used if the author ORCID is unknown. Institutional agents could be identified by an International Standard Name Identifier ('ISNI') code.

URI: [biolink:agent_id](https://w3id.org/biolink/vocab/agent_id)


## Domain and Range

[Agent](Agent.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents

 *  is_a: [id](id.md)

## Children


## Used by

 * [Agent](Agent.md)
